abacusai.nlp_classification_prediction — AbacusAI documentation

# `abacusai.nlp_classification_prediction`

## Module Contents

### Classes

`NlpClassificationPrediction` | param client An authenticated API Client instance

class abacusai.nlp_classification_prediction.NlpClassificationPrediction(client)

  Bases: `abacusai.return_class.AbstractApiClass`

  Parameters

    client (ApiClient) – An authenticated API Client instance

  __repr__(self)

    Return repr(self).

  to_dict(self)

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict